Package: gbm
Version: 2.1.3
Date: 2017-03-21
Title: Generalized Boosted Regression Models
Author: Greg Ridgeway <gregridgeway@gmail.com> with contributions from
        others
Maintainer: ORPHANED
Depends: R (>= 2.9.0), survival, lattice, splines, parallel
Suggests: RUnit
Description: An implementation of extensions to Freund and
        Schapire's AdaBoost algorithm and Friedman's gradient boosting
        machine. Includes regression methods for least squares,
        absolute loss, t-distribution loss, quantile regression,
        logistic, multinomial logistic, Poisson, Cox proportional
        hazards partial likelihood, AdaBoost exponential loss,
        Huberized hinge loss, and Learning to Rank measures
        (LambdaMart).
License: GPL (>= 2) | file LICENSE
URL: http://code.google.com/p/gradientboostedmodels/
Packaged: 2017-03-21 06:44:01 UTC; ripley
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2017-03-21 06:48:03 UTC
X-CRAN-Original-Maintainer: Harry Southworth
        <harry.southworth@gmail.com>
X-CRAN-Comment: Orphaned on 2017-03-21 as long-standing errors were not
        corrected.  NMU by CRAN team.
Built: R 3.4.1; x86_64-w64-mingw32; 2018-08-04 21:27:42 UTC; windows
Archs: x64
