Package: gbm
Version: 2.1.8
Title: Generalized Boosted Regression Models
Authors@R: c(
  person("Brandon", "Greenwell",
         email = "greenwell.brandon@gmail.com",
         role = c("aut", "cre"),
         comment = c(ORCID = "0000-0002-8120-0084")),
  person("Bradley", "Boehmke",
         email = "bradleyboehmke@gmail.com",
         role = "aut",
         comment = c(ORCID = "0000-0002-3611-8516")),
  person("Jay", "Cunningham",
         email = "james@notbadafterall.com",
         role = "aut"),
  person("GBM", "Developers", 
         role = "aut", 
         comment = "https://github.com/gbm-developers")
  )
Depends: R (>= 2.9.0)
Imports: lattice, parallel, survival
Suggests: covr, gridExtra, knitr, pdp, RUnit, splines, tinytest, vip,
        viridis
Description: An implementation of extensions to Freund and Schapire's AdaBoost 
  algorithm and Friedman's gradient boosting machine. Includes regression 
  methods for least squares, absolute loss, t-distribution loss, quantile 
  regression, logistic, multinomial logistic, Poisson, Cox proportional hazards 
  partial likelihood, AdaBoost exponential loss, Huberized hinge loss, and 
  Learning to Rank measures (LambdaMart). Originally developed by Greg Ridgeway.
License: GPL (>= 2) | file LICENSE
URL: https://github.com/gbm-developers/gbm
BugReports: https://github.com/gbm-developers/gbm/issues
Encoding: UTF-8
RoxygenNote: 7.1.1
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2020-07-13 15:15:55 UTC; b780620
Author: Brandon Greenwell [aut, cre] (<https://orcid.org/0000-0002-8120-0084>),
  Bradley Boehmke [aut] (<https://orcid.org/0000-0002-3611-8516>),
  Jay Cunningham [aut],
  GBM Developers [aut] (https://github.com/gbm-developers)
Maintainer: Brandon Greenwell <greenwell.brandon@gmail.com>
Repository: CRAN
Date/Publication: 2020-07-15 10:00:02 UTC
Built: R 4.1.0; x86_64-w64-mingw32; 2021-05-25 22:11:06 UTC; windows
Archs: x64
