# Generated by roxygen2: do not edit by hand

S3method(plot,gbm)
S3method(predict,gbm)
S3method(print,gbm)
S3method(summary,gbm)
export(basehaz.gbm)
export(calibrate.plot)
export(checkID)
export(checkMissing)
export(checkOffset)
export(checkWeights)
export(gbm)
export(gbm.conc)
export(gbm.fit)
export(gbm.loss)
export(gbm.more)
export(gbm.perf)
export(gbm.roc.area)
export(gbmCluster)
export(gbmCrossVal)
export(gbmCrossValErr)
export(gbmCrossValModelBuild)
export(gbmCrossValPredictions)
export(gbmDoFold)
export(getCVgroup)
export(getStratify)
export(getVarNames)
export(guessDist)
export(interact.gbm)
export(ir.measure.auc)
export(ir.measure.conc)
export(ir.measure.map)
export(ir.measure.mrr)
export(ir.measure.ndcg)
export(perf.pairwise)
export(permutation.test.gbm)
export(plot.gbm)
export(predict.gbm)
export(pretty.gbm.tree)
export(quantile.rug)
export(reconstructGBMdata)
export(relative.influence)
export(show.gbm)
export(summary.gbm)
export(test.gbm)
export(test.relative.influence)
export(validate.gbm)
import(lattice)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,rug)
importFrom(graphics,segments)
importFrom(graphics,title)
importFrom(stats,approx)
importFrom(stats,binomial)
importFrom(stats,delete.response)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,loess)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.offset)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.pass)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,reformulate)
importFrom(stats,reorder)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,supsmu)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,weighted.mean)
importFrom(survival,Surv)
useDynLib(gbm, .registration = TRUE)
